<?php
namespace news\system\event\listener;
use news\data\news\AccessibleNewsList;
use news\data\category\NewsCategory;
use wcf\system\WCF;
use wcf\system\application\ApplicationHandler;
use wcf\system\event\IEventListener;
use wcf\system\exception\SystemException;
/**
 * @author	 Tino Stange
 * @package	eu.t1n0.newsExtendedSearch
 */
class NewsExtendedSearchActionListener implements IEventListener {
	private $eventObj = null;

	/**
	 * @see	\wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		$this->eventObj = $eventObj;
		$this->eventObj->data['newsEntries'] = $this->getEntries();
	}

	/**
	 * Selects all matching news entries from the database
	 * @return array	the matching news entries
	 */
	private function getEntries() {
		// don't have permissions to access any news entry
		if (!WCF::getSession()->getPermission('user.news.canReadNews')) {
			return array();
		}
		
		$entryList = new AccessibleNewsList(NewsCategory::getCategories());
		$entryList->getConditionBuilder()->add('((news.subject LIKE ? AND (SELECT SUM(languageItem) FROM wcf'.WCF_N.'_language_item WHERE languageItem = news.subject) IS NULL AND (SELECT SUM(languageItem) FROM wcf'.WCF_N.'_language_item WHERE languageItem = news.subject AND languageItemValue LIKE ?) IS NULL) OR (news.subject NOT LIKE ? AND (SELECT SUM(languageItem) FROM wcf'.WCF_N.'_language_item WHERE languageItem = news.subject AND languageItemValue LIKE ?) IS NOT NULL))', array($this->eventObj->getSearchString("startend"), $this->eventObj->getSearchString("startend"), $this->eventObj->getSearchString("startend"), $this->eventObj->getSearchString("startend")));
		$entryList->sqlOrderBy = EXTENDED_SEARCH_SEARCH_NEWS_ORDER . ' ' . EXTENDED_SEARCH_SEARCH_NEWS_ORDER_SORT;
		$entryList->sqlLimit = EXTENDED_SEARCH_SEARCH_NEWS_SOURCE_COUNT;
		$entryList->readObjects();
		
		$entries = array();
		$entries['title'] = WCF::getLanguage()->get('news.extendedSearch.type.entries');
		$entries['position'] = 'right';

		// if the current application is correct, we want to display the results at the top, so set a nice value of 1
		$activeApplicationAbbr = ApplicationHandler::getInstance()->getActiveApplication()->getAbbreviation();
		if ($activeApplicationAbbr === 'news') {
			$entries['niceValue'] = 1;
		}

		$entries['data'] = array();
		$count = 0;
		foreach ($entryList->getObjects() as $entry) {
			$count++;
			
			$entries['data'][$count] = array(
				'label' => WCF::getLanguage()->getDynamicVariable($entry->subject),
				'link' => $entry->getLink(),
				'hitCount' => $entry->views
			);
		}

		return $entries;
	}
}